Module Name:    src
Committed By:   jmcneill
Date:           Wed Aug 19 13:38:51 UTC 2009

Modified Files:
        src/sys/dev/usb: pseye.c

Log Message:
s/PLAYSTATION/PlayStation/


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.12 src/sys/dev/usb/pseye.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/pseye.c
diff -u src/sys/dev/usb/pseye.c:1.11 src/sys/dev/usb/pseye.c:1.12
--- src/sys/dev/usb/pseye.c:1.11	Tue Feb  3 13:31:24 2009
+++ src/sys/dev/usb/pseye.c	Wed Aug 19 13:38:51 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: pseye.c,v 1.11 2009/02/03 13:31:24 jmcneill Exp $ */
+/* $NetBSD: pseye.c,v 1.12 2009/08/19 13:38:51 jmcneill Exp $ */
 
 /*-
  * Copyright (c) 2008 Jared D. McNeill <[email protected]>
@@ -27,7 +27,7 @@
  */
 
 /*
  * Sony PLAYSTATION(R) Eye Driver
  *
  * The only documentation we have for this part is based on a series
  * of forum postings by Jim Paris on ps2dev.org. Many thanks for
@@ -37,7 +37,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pseye.c,v 1.11 2009/02/03 13:31:24 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pseye.c,v 1.12 2009/08/19 13:38:51 jmcneill Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -707,7 +707,7 @@
 static const char *
 pseye_get_devname(void *opaque)
 {
-	return "PLAYSTATION(R) Eye";
+	return "PlayStation Eye";
 }
 
 static int
@@ -27,7 +27,7 @@
 
 /*
- * Sony PLAYSTATION(R) Eye Driver
+ * Sony PlayStation Eye Driver
  *
  * The only documentation we have for this part is based on a series

Reply via email to